@@ -9,14 +9,14 @@ test_that("regex works correctly in aov_car when also having within factors outs
 test_that("another label bug (May 2014)", {
   data("sk2011.1")
   levels(sk2011.1$inference) <- c("A+:D-", "A+:D+", "A-:D+", "A- : D-")
-  expect_is(suppressWarnings(aov_ez("id", "response", sk2011.1, between = "instruction", within = c("type", "inference"), return = "Anova")), "Anova.mlm")  
+  expect_is(aov_ez("id", "response", sk2011.1, between = "instruction", within = c("type", "inference"), return = "Anova", fun_aggregate = mean), "Anova.mlm")  
 })
 
 test_that("orig label bug", {
   data(obk.long)
   obk2 <- obk.long
   levels(obk2$phase) <- c("fup test", "post-hans", "pre tenetious")
-  expect_is(suppressWarnings(aov_car(value ~ treatment * gender + age + Error(id/phase*hour), data = obk2, factorize=FALSE, return = "Anova")), "Anova.mlm")
+  expect_is(aov_car(value ~ treatment * gender + age + Error(id/phase*hour), data = obk2, factorize=FALSE, return = "Anova"), "Anova.mlm")
 })
 
 test_that("ANCOVA check bug (reported by Gang Chen), January 2013", {
@@ -143,8 +143,8 @@ test_that("ANCOVA check bug (reported by Gang Chen), January 2013", {
 2117 HC F 01_02 1.663 -0.014 0.917999999999999 1.293 3.7965
 ")
   dat$ID <- as.factor(dat$ID)
-  fm <- suppressWarnings(aov_car(Value ~ Propdd00 + Group + Gender + GAS0 + MAD0 + CPD0 + Error(ID/ROI), data=dat, factorize=FALSE, return = "Anova"))
-  fm0 <- suppressWarnings(aov_car(Value ~ MAD0 + CPD0 + Error(ID/ROI), data=dat, factorize=FALSE, return='afex_aov'))
+  fm <- aov_car(Value ~ Propdd00 + Group + Gender + GAS0 + MAD0 + CPD0 + Error(ID/ROI), data=dat, factorize=FALSE, return = "Anova")
+  fm0 <- aov_car(Value ~ MAD0 + CPD0 + Error(ID/ROI), data=dat, factorize=FALSE, return='afex_aov')
   expect_is(fm, "Anova.mlm")
   expect_is(fm0, "afex_aov")
 })
@@ -196,3 +196,33 @@ test_that("works with dplyr data.frames (see https://github.com/singmann/afex/is
     expect_is(aov_ez("id", "rt", md2, within = c("angle", "noise"), anova_table=list(correction = "none", es = "none")), "afex_aov") 
   }
 })
+
+test_that("return='nice' works", {
+  data(md_12.1)
+  expect_is(aov_ez("id", "rt", md_12.1, within = c("angle", "noise"), return = "nice"), "data.frame")
+})
+
+
+test_that("aov_car works with column names containing spaces: https://github.com/singmann/afex/issues/22", {
+  data <- list("dependent" = rnorm(100), "RM Factor 1" = factor(rep(c("Level 1", "Level 2"), 50)), "subject" = factor(rep(1:50, each = 2)))
+  attr(data, 'row.names') <- seq_len(length(data[[1]]))
+  attr(data, 'class') <- 'data.frame'
+  
+  expect_is(aov_car(dependent ~ `RM Factor 1` + Error(subject/(`RM Factor 1`)), data),  "afex_aov")
+  expect_is(aov_4(dependent ~ `RM Factor 1` + (`RM Factor 1`|subject), data), "afex_aov")
+  expect_is(aov_ez("subject", "dependent", data, within = "RM Factor 1"), "afex_aov")
+})
+
+
+test_that("aov_ez works with multiple covariates", {
+  skip_if_not_installed("psych")
+  require(psych)
+  data(msq)
+  msq2 <- msq[!is.na(msq$Extraversion),]
+  msq2 <- droplevels(msq2[msq2$ID != "18",])
+  msq2$TOD <- msq2$TOD-mean(msq2$TOD)
+  msq2$MSQ_Time <- msq2$MSQ_Time-mean(msq2$MSQ_Time)
+  msq2$condition <- msq2$condition-mean(msq2$condition) # that is somewhat stupid
+  expect_is(aov_ez(data=msq2, dv="Extraversion", id = "ID", between = "condition", 
+    covariate=c("TOD", "MSQ_Time"), factorize=FALSE, fun_aggregate = mean), "afex_aov")
+})
\ No newline at end of file
